==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'C’hwitet eo bet ar sindikadur : dilennus eo ar backend kinniget, pe ne ginnig pennad ebet.',
	'avis_echec_syndication_02' => 'C’hwitet eo bet ar sindikadur : n’eus ket tu da dizhout backend al lec’hienn-mañ.',
	'avis_site_introuvable' => 'N’haller ket kavout al lec’hienn-se',
	'avis_site_syndique_probleme' => 'Diwallit : ur gudenn zo savet gant sindikadur al lec’hienn-mañ ; diwar se eo ehanet ar reizhiad e-pad ur pennadig amzer. Gwiriit chomlec’h restr sindikadiñ al lec’hienn-mañ (<b>@url_syndic@</b>), ha klaskit adtapout an titouroù en dro.',
	'avis_sites_probleme_syndication' => 'Al lec’hiennoù-se o deus bet ur gudenn sindikadiñ',
	'avis_sites_syndiques_probleme' => 'Kudennoù zo savet gant al lec’hiennoù sindikadet-se',

	// B
	'bouton_radio_modere_posteriori' => 'gwiriañ goude an embann', # MODIF
	'bouton_radio_modere_priori' => 'gwiriañ a-raok embann', # MODIF
	'bouton_radio_non_syndication' => 'Sindikadur ebet',
	'bouton_radio_syndication' => 'Sindikadur :',

	// E
	'entree_adresse_fichier_syndication' => 'Chomlec’h ar restr evit ar sindikadur :',
	'entree_adresse_site' => '<b>Chomlec’h al lec’hienn</b> [Rekis]',
	'entree_description_site' => 'Deskrivadenn al lec’hienn',

	// F
	'form_prop_nom_site' => 'Anv al lec’hienn',

	// I
	'icone_modifier_site' => 'Kemmañ al lec’hienn-mañ',
	'icone_referencer_nouveau_site' => 'Menegeriñ ul lec’hienn nevez',
	'icone_voir_sites_references' => 'Gwelet al lec’hiennoù menegeret',
	'info_a_valider' => '[da wiriañ]',
	'info_bloquer' => 'stankañ',
	'info_bloquer_lien' => 'Stankañ al liamm-mañ',
	'info_derniere_syndication' => 'Sindikadur diwezhañ al lec’hienn-mañ a zo bet graet d’an',
	'info_liens_syndiques_1' => 'Liammoù sindikadet',
	'info_liens_syndiques_2' => 'o c’hortoz bezañ asantet.',
	'info_nom_site_2' => '<b>Anv al lec’hienn</b> [Rekis]',
	'info_panne_site_syndique' => 'Sac’het eo al lec’hienn sindikadet',
	'info_probleme_grave' => 'kudenn a',
	'info_question_proposer_site' => 'Piv a c’hall kinnig lec’hiennoù menegeret ?',
	'info_retablir_lien' => 'adlakaat al liamm-mañ',
	'info_site_attente' => 'Lec’hienn a c’hortoz bezañ kadarnaet',
	'info_site_propose' => 'Lec’hienn kinniget d’an :',
	'info_site_reference' => 'Lec’hienn menegeret enlinenn',
	'info_site_refuse' => 'Lec’hienn bet nac’het',
	'info_site_syndique' => 'Sindikadet eo al lec’hienn-mañ...', # MODIF
	'info_site_valider' => 'Lec’hiennoù da aprouiñ',
	'info_sites_referencer' => 'Menegeriñ ul lec’hienn',
	'info_sites_refuses' => 'Al lec’hiennoù bet nac’het',
	'info_statut_site_1' => 'Al lec’hienn-mañ zo :',
	'info_statut_site_2' => 'Embannet',
	'info_statut_site_3' => 'Kinniget',
	'info_statut_site_4' => 'Er pod-lastez', # MODIF
	'info_syndication' => 'Sindikadur :',
	'info_syndication_articles' => 'pennad(où)',
	'item_bloquer_liens_syndiques' => 'Stankañ al liammoù sindikadet evit o c’hadarnaat',
	'item_gerer_annuaire_site_web' => 'Merañ ur roll lec’hiennoù Web',
	'item_non_bloquer_liens_syndiques' => 'Arabat stankañ al liammoù deuet diwar ar sindikadañ',
	'item_non_gerer_annuaire_site_web' => 'Diweredekaat roll al lec’hiennoù Web',
	'item_non_utiliser_syndication' => 'Na implijout ar sindikadañ emgefre',
	'item_utiliser_syndication' => 'Implijout ar sindikadur emgefre',

	// L
	'lien_mise_a_jour_syndication' => 'Hizivaat bremañ',
	'lien_nouvelle_recuperation' => 'Klask adtapout an titouroù en-dro',

	// S
	'syndic_choix_moderation' => 'Petra ober gant al liammoù a zeu o tont eus al lec’hienn-mañ ?',
	'syndic_choix_oublier' => 'Petra ober gant al liammoù n’emaint ket er restr sindikadañ ken ?',
	'syndic_choix_resume' => 'Lec’hiennoù zo a embann testenn glok ar pennadoù. Pa c’haller he c’haout, ha fellout a ra deoc’h sindikadañ? :',
	'syndic_lien_obsolete' => 'liamm dispredet',
	'syndic_option_miroir' => 'stankañ anezho ent emgefre',
	'syndic_option_oubli' => 'diverkañ anezho (goude @mois@ miz)',
	'syndic_option_resume_non' => 'endalc’had klok ar pennadoù (er furmad HTML)',
	'syndic_option_resume_oui' => 'un diverrañ hepken (e furmad testenn)',
	'syndic_options' => 'Dibarzhioù sindikadañ :',

	// T
	'texte_liens_sites_syndiques' => 'Gallout a ra al liammoù deuet diwar lec’hiennoù sindikadet bezañ stanket a-raok embann ;
   amañ dindan emañ diskouezet reizhadenn dre ziouer al lec’hiennoù sindikadet goude dezho bezañ bet krouet.
   Goude e c’hallit atav dibab distankañ pep liamm unan-hag-unan pe dibab, evit pep lec’hienn, stankañ al liammoù a zeu eus lec’hienn pe lec’hienn.', # MODIF
	'texte_messages_publics' => 'Kemennadennoù foran ar pennad :',
	'texte_non_fonction_referencement' => 'Gallout a rit dibab chom hep ober gant an arc’hwel emgefre-mañ, ha merkañ an elfennoù diwar-benn al lec’hienn hoc’h-unan...', # MODIF
	'texte_referencement_automatique' => '<b>Menegeradur emgefre ul lec’hienn</b><br />Gallout a rit menegeriñ buan ul lec’hienn Web en ur verkañ skrivañ amañ dindan hec’h URL, pe chomlec’h he restr sindikadañ. SPIP a zastumo e-unan an titouroù diwar-benn al lec’hienn (titl, deskrivadur, ...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Gwiriit an titouroù bet roet gant <tt>@url@</tt> a-raok enrollañ.',
	'texte_syndication' => 'Pa vez aotreet gant ul lec’hienn Web eo posupl adtapout en un doare emgefre roll an nevezinti.
  Evit se eo dav gweredekaat ar sindikadur.
  <blockquote><i>Herberc’hierien a ziweredeka an arc’hwel-se ; 
  neuze n’hallit ket implijout ar sindikadur adalek ho lec’hienn.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Pennadoù sindikadet tennet eus al lec’hienn-mañ',
	'titre_dernier_article_syndique' => 'Pennadoù sindikadet da ziwezhañ',
	'titre_page_sites_tous' => 'Al lec’hiennoù menegeret',
	'titre_referencement_sites' => 'Menegeriñ lec’hiennoù ha sindikadañ',
	'titre_site_numero' => 'LEC’HIENN NIVERENN :',
	'titre_sites_proposes' => 'Al lec’hiennoù kinniget',
	'titre_sites_references_rubrique' => 'Al lec’hiennoù menegeret er rummad-mañ',
	'titre_sites_syndiques' => 'Al lec’hiennoù sindikadet dre RSS',
	'titre_sites_tous' => 'Al lec’hiennoù menegeret',
	'titre_syndication' => 'Sindikadañ lec’hiennoù'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En gortoz ',
	'articles_meme_auteur' => 'Bep pennadou gant ar saver-mañ',
	'articles_off' => 'Stanket',
	'articles_publie' => 'Embannnet',
	'articles_refuse' => 'Lazhet', # RELIRE
	'articles_tous' => 'Pep tra',
	'avis_echec_syndication_01' => 'C’hwitet eo bet ar sindikadur : dilennus eo ar backend kinniget, pe ne ginnig pennad ebet.',
	'avis_echec_syndication_02' => 'C’hwitet eo bet ar sindikadur : n’eus ket tu da dizhout backend al lec’hienn-mañ.',
	'avis_site_introuvable' => 'N’haller ket kavout al lec’hienn-se',
	'avis_site_syndique_probleme' => 'Diwallit : ur gudenn zo savet gant sindikadur al lec’hienn-mañ ; diwar se eo ehanet ar reizhiad e-pad ur pennadig amzer. Gwiriit chomlec’h restr sindikadiñ al lec’hienn-mañ (<b>@url_syndic@</b>), ha klaskit adtapout an titouroù en dro.',
	'avis_sites_probleme_syndication' => 'Al lec’hiennoù-se o deus bet ur gudenn sindikadiñ',
	'avis_sites_syndiques_probleme' => 'Kudennoù zo savet gant al lec’hiennoù sindikadet-se',

	// B
	'bouton_exporter' => 'Ezkas', # RELIRE
	'bouton_importer' => 'Dikas',
	'bouton_radio_modere_posteriori' => 'adwelet goude an embann',
	'bouton_radio_modere_priori' => 'adwelet a-raok an embann',
	'bouton_radio_non_syndication' => 'Sindikadur ebet',
	'bouton_radio_syndication' => 'Sindikadur :',

	// E
	'entree_adresse_fichier_syndication' => 'Chomlec’h ar restr evit ar sindikadur :',
	'entree_adresse_site' => '<b>Chomlec’h al lec’hienn</b> [Rekis]',
	'entree_description_site' => 'Deskrivadenn al lec’hienn',
	'erreur_fichier_incorrect' => 'Diposubl da lenn ar fichennaoueg',

	// F
	'form_prop_nom_site' => 'Anv al lec’hienn',

	// I
	'icone_modifier_site' => 'Kemmañ al lec’hienn-mañ',
	'icone_referencer_nouveau_site' => 'Menegeriñ ul lec’hienn nevez',
	'icone_supprimer_article' => 'Larzh ar pennad-mañ',
	'icone_valider_article' => 'Gwirian ar pennad-mañ',
	'icone_valider_articles' => 'Gwirian ar pennad-mañ',
	'icone_voir_sites_references' => 'Gwelet al lec’hiennoù menegeret',
	'info_1_article_syndique' => '1 pennad-skrid sindikadet',
	'info_1_site' => '1 lec’hienn',
	'info_1_site_importe' => 'Unan lech’ienn a zo bet ezkas',
	'info_a_valider' => '[da wiriañ]',
	'info_aucun_article_syndique' => 'Pennad-skrid amaezhiet ebet',
	'info_aucun_site' => 'lec’hienn ebet',
	'info_bloquer' => 'stankañ',
	'info_bloquer_lien' => 'Stankañ al liamm-mañ',
	'info_derniere_syndication' => 'Sindikadur diwezhañ al lec’hienn-mañ a zo bet graet d’an',
	'info_liens_syndiques_1' => 'Liammoù sindikadet',
	'info_liens_syndiques_2' => 'o c’hortoz bezañ asantet.',
	'info_nb_articles_syndiques' => '@nb@ pennadoù-skrid amaezhiet',
	'info_nb_sites' => '@nb@ lec’hiennoù',
	'info_nom_site_2' => '<b>Anv al lec’hienn</b> [Rekis]',
	'info_panne_site_syndique' => 'Sac’het eo al lec’hienn sindikadet',
	'info_probleme_grave' => 'kudenn a',
	'info_question_proposer_site' => 'Piv a c’hall kinnig lec’hiennoù menegeret ?',
	'info_retablir_lien' => 'adlakaat al liamm-mañ',
	'info_site_attente' => 'Lec’hienn a c’hortoz bezañ kadarnaet',
	'info_site_propose' => 'Lec’hienn kinniget d’an :',
	'info_site_reference' => 'Lec’hienn menegeret enlinenn',
	'info_site_refuse' => 'Lec’hienn bet nac’het',
	'info_site_syndique' => 'Sindikadet eo al lec’hienn-mañ...',
	'info_site_valider' => 'Lec’hiennoù da aprouiñ',
	'info_sites_referencer' => 'Menegeriñ ul lec’hienn',
	'info_sites_refuses' => 'Al lec’hiennoù bet nac’het',
	'info_statut_site_1' => 'Al lec’hienn-mañ zo :',
	'info_statut_site_2' => 'Embannet',
	'info_statut_site_3' => 'Kinniget',
	'info_statut_site_4' => 'Er pod-lastez',
	'info_syndication' => 'Sindikadur :',
	'info_syndication_articles' => 'pennad(où)',
	'item_bloquer_liens_syndiques' => 'Stankañ al liammoù sindikadet evit o c’hadarnaat',
	'item_gerer_annuaire_site_web' => 'Merañ ur roll lec’hiennoù Web',
	'item_non_bloquer_liens_syndiques' => 'Arabat stankañ al liammoù deuet diwar ar sindikadañ',
	'item_non_gerer_annuaire_site_web' => 'Diweredekaat roll al lec’hiennoù Web',
	'item_non_utiliser_syndication' => 'Na implijout ar sindikadañ emgefre',
	'item_utiliser_syndication' => 'Implijout ar sindikadur emgefre',

	// L
	'label_exporter_publie_seulement_1' => ' Digas nemetken ar lec’hiennoù embannet',
	'lien_mise_a_jour_syndication' => 'Hizivaat bremañ',
	'lien_nouvelle_recuperation' => 'Klask adtapout an titouroù en-dro',

	// S
	'statut_off' => 'Larzhet',
	'statut_prop' => 'En gortoz',
	'statut_publie' => 'Embannet',
	'syndic_choix_moderation' => 'Petra ober gant al liammoù a zeu o tont eus al lec’hienn-mañ ?',
	'syndic_choix_oublier' => 'Petra ober gant al liammoù n’emaint ket er restr sindikadañ ken ?',
	'syndic_choix_resume' => 'Lec’hiennoù zo a embann testenn glok ar pennadoù. Pa c’haller he c’haout, ha fellout a ra deoc’h sindikadañ? :',
	'syndic_lien_obsolete' => 'liamm dispredet',
	'syndic_option_miroir' => 'stankañ anezho ent emgefre',
	'syndic_option_oubli' => 'diverkañ anezho (goude @mois@ miz)',
	'syndic_option_resume_non' => 'endalc’had klok ar pennadoù (er furmad HTML)',
	'syndic_option_resume_oui' => 'un diverrañ hepken (e furmad testenn)',
	'syndic_options' => 'Dibarzhioù sindikadañ :',

	// T
	'texte_liens_sites_syndiques' => 'Gallout a ra al liammoù deuet diwar lec’hiennoù sindikadet bezañ stanket a-raok embann ;
   amañ dindan emañ diskouezet reizhadenn dre ziouer al lec’hiennoù sindikadet goude dezho bezañ bet krouet.
   Goude e c’hallit atav dibab distankañ pep liamm unan-hag-unan pe dibab, evit pep lec’hienn, stankañ al liammoù a zeu eus lec’hienn pe lec’hienn.', # MODIF
	'texte_messages_publics' => 'Kemennadennoù foran ar pennad :',
	'texte_non_fonction_referencement' => 'Gallout a rit dibab chom hep ober gant an arc’hwel emgefre-mañ, ha merkañ an elfennoù diwar-benn al lec’hienn hoc’h-unan...', # RELIRE
	'texte_referencement_automatique' => '<b>Menegeradur emgefre ul lec’hienn</b><br />Gallout a rit menegeriñ buan ul lec’hienn Web en ur verkañ skrivañ amañ dindan hec’h URL, pe chomlec’h he restr sindikadañ. SPIP a zastumo e-unan an titouroù diwar-benn al lec’hienn (titl, deskrivadur, ...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Gwiriit an titouroù bet roet gant <tt>@url@</tt> a-raok enrollañ.',
	'texte_syndication' => 'Pa vez aotreet gant ul lec’hienn Web eo posupl adtapout en un doare emgefre roll an nevezinti.
  Evit se eo dav gweredekaat ar sindikadur.
  <blockquote><i>Herberc’hierien a ziweredeka an arc’hwel-se ; 
  neuze n’hallit ket implijout ar sindikadur adalek ho lec’hienn.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Pennadoù sindikadet tennet eus al lec’hienn-mañ',
	'titre_dernier_article_syndique' => 'Pennadoù sindikadet da ziwezhañ',
	'titre_page_sites_tous' => 'Al lec’hiennoù menegeret',
	'titre_referencement_sites' => 'Menegeriñ lec’hiennoù ha sindikadañ',
	'titre_site_numero' => 'LEC’HIENN NIVERENN :',
	'titre_sites_proposes' => 'Al lec’hiennoù kinniget',
	'titre_sites_references_rubrique' => 'Al lec’hiennoù menegeret er rummad-mañ',
	'titre_sites_syndiques' => 'Al lec’hiennoù sindikadet dre RSS',
	'titre_sites_tous' => 'Al lec’hiennoù menegeret',
	'titre_syndication' => 'Sindikadañ lec’hiennoù'
);

?>
